<?php
/**
 * @name		WebTotem Security
 * @package		pkg_wtotem
 * @copyright	Copyright (C) 2023. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		WebTotem team
 */


Namespace WebTotem;

// No direct access
defined('_JEXEC') or die;
defined('WEBTOTEM_INIT') or die;

/**
 * WebTotem CountryManager class for Wordpress.
 */
class CountryManager {

	/**
	 * An array of country code => country name pairs.
	 */
	protected $countries;

	/**
	 * Get an array of all two-letter country code => country name pairs.
	 *
	 * @return array
	 *   An array of country code => country name pairs.
	 */
	public static function getStandardList() {
		$countries = [
			'AC' => \JText::_('WTOTEM_ASCENSION_ISLAND'),
			'AD' => \JText::_('WTOTEM_ANDORRA'),
			'AE' => \JText::_('WTOTEM_UNITED_ARAB_EMIRATES'),
			'AF' => \JText::_('WTOTEM_AFGHANISTAN'),
			'AG' => \JText::_('WTOTEM_ANTIGUA_BARBUDA'),
			'AI' => \JText::_('WTOTEM_ANGUILLA'),
			'AL' => \JText::_('WTOTEM_ALBANIA'),
			'AM' => \JText::_('WTOTEM_ARMENIA'),
			'AN' => \JText::_('WTOTEM_NETHERLANDS_ANTILLES'),
			'AO' => \JText::_('WTOTEM_ANGOLA'),
			'AQ' => \JText::_('WTOTEM_ANTARCTICA'),
			'AR' => \JText::_('WTOTEM_ARGENTINA'),
			'AS' => \JText::_('WTOTEM_AMERICAN_SAMOA'),
			'AT' => \JText::_('WTOTEM_AUSTRIA'),
			'AU' => \JText::_('WTOTEM_AUSTRALIA'),
			'AW' => \JText::_('WTOTEM_ARUBA'),
			'AX' => \JText::_('WTOTEM_ALAND_ISLANDS'),
			'AZ' => \JText::_('WTOTEM_AZERBAIJAN'),
			'BA' => \JText::_('WTOTEM_BOSNIA_HERZEGOVINA'),
			'BB' => \JText::_('WTOTEM_BARBADOS'),
			'BD' => \JText::_('WTOTEM_BANGLADESH'),
			'BE' => \JText::_('WTOTEM_BELGIUM'),
			'BF' => \JText::_('WTOTEM_BURKINA_FASO'),
			'BG' => \JText::_('WTOTEM_BULGARIA'),
			'BH' => \JText::_('WTOTEM_BAHRAIN'),
			'BI' => \JText::_('WTOTEM_BURUNDI'),
			'BJ' => \JText::_('WTOTEM_BENIN'),
			'BL' => \JText::_('WTOTEM_ST_BARTHELEMY'),
			'BM' => \JText::_('WTOTEM_BERMUDA'),
			'BN' => \JText::_('WTOTEM_BRUNEI'),
			'BO' => \JText::_('WTOTEM_BOLIVIA'),
			'BQ' => \JText::_('WTOTEM_CARIBBEAN_NETHERLANDS'),
			'BR' => \JText::_('WTOTEM_BRAZIL'),
			'BS' => \JText::_('WTOTEM_BAHAMAS'),
			'BT' => \JText::_('WTOTEM_BHUTAN'),
			'BV' => \JText::_('WTOTEM_BOUVET_ISLAND'),
			'BW' => \JText::_('WTOTEM_BOTSWANA'),
			'BY' => \JText::_('WTOTEM_BELARUS'),
			'BZ' => \JText::_('WTOTEM_BELIZE'),
			'CA' => \JText::_('WTOTEM_CANADA'),
			'CC' => \JText::_('WTOTEM_COCOS_KEELING_ISLANDS'),
			'CD' => \JText::_('WTOTEM_CONGO_KINSHASA'),
			'CF' => \JText::_('WTOTEM_CENTRAL_AFRICAN_REPUBLIC'),
			'CG' => \JText::_('WTOTEM_CONGO_BRAZZAVILLE'),
			'CH' => \JText::_('WTOTEM_SWITZERLAND'),
			'CI' => \JText::_('WTOTEM_COTE_DIVOIRE'),
			'CK' => \JText::_('WTOTEM_COOK_ISLANDS'),
			'CL' => \JText::_('WTOTEM_CHILE'),
			'CM' => \JText::_('WTOTEM_CAMEROON'),
			'CN' => \JText::_('WTOTEM_CHINA'),
			'CO' => \JText::_('WTOTEM_COLOMBIA'),
			'CP' => \JText::_('WTOTEM_CLIPPERTON_ISLAND'),
			'CR' => \JText::_('WTOTEM_COSTA_RICA'),
			'CU' => \JText::_('WTOTEM_CUBA'),
			'CV' => \JText::_('WTOTEM_CAPE_VERDE'),
			'CW' => \JText::_('WTOTEM_CURACAO'),
			'CX' => \JText::_('WTOTEM_CHRISTMAS_ISLAND'),
			'CY' => \JText::_('WTOTEM_CYPRUS'),
			'CZ' => \JText::_('WTOTEM_CZECHIA'),
			'DE' => \JText::_('WTOTEM_GERMANY'),
			'DG' => \JText::_('WTOTEM_DIEGO_GARCIA'),
			'DJ' => \JText::_('WTOTEM_DJIBOUTI'),
			'DK' => \JText::_('WTOTEM_DENMARK'),
			'DM' => \JText::_('WTOTEM_DOMINICA'),
			'DO' => \JText::_('WTOTEM_DOMINICAN_REPUBLIC'),
			'DZ' => \JText::_('WTOTEM_ALGERIA'),
			'EA' => \JText::_('WTOTEM_CEUTA_MELILLA'),
			'EC' => \JText::_('WTOTEM_ECUADOR'),
			'EE' => \JText::_('WTOTEM_ESTONIA'),
			'EG' => \JText::_('WTOTEM_EGYPT'),
			'EH' => \JText::_('WTOTEM_WESTERN_SAHARA'),
			'ER' => \JText::_('WTOTEM_ERITREA'),
			'ES' => \JText::_('WTOTEM_SPAIN'),
			'ET' => \JText::_('WTOTEM_ETHIOPIA'),
			'FI' => \JText::_('WTOTEM_FINLAND'),
			'FJ' => \JText::_('WTOTEM_FIJI'),
			'FK' => \JText::_('WTOTEM_FALKLAND_ISLANDS'),
			'FM' => \JText::_('WTOTEM_MICRONESIA'),
			'FO' => \JText::_('WTOTEM_FAROE_ISLANDS'),
			'FR' => \JText::_('WTOTEM_FRANCE'),
			'GA' => \JText::_('WTOTEM_GABON'),
			'GB' => \JText::_('WTOTEM_UNITED_KINGDOM'),
			'GD' => \JText::_('WTOTEM_GRENADA'),
			'GE' => \JText::_('WTOTEM_GEORGIA'),
			'GF' => \JText::_('WTOTEM_FRENCH_GUIANA'),
			'GG' => \JText::_('WTOTEM_GUERNSEY'),
			'GH' => \JText::_('WTOTEM_GHANA'),
			'GI' => \JText::_('WTOTEM_GIBRALTAR'),
			'GL' => \JText::_('WTOTEM_GREENLAND'),
			'GM' => \JText::_('WTOTEM_GAMBIA'),
			'GN' => \JText::_('WTOTEM_GUINEA'),
			'GP' => \JText::_('WTOTEM_GUADELOUPE'),
			'GQ' => \JText::_('WTOTEM_EQUATORIAL_GUINEA'),
			'GR' => \JText::_('WTOTEM_GREECE'),
			'GS' => \JText::_('WTOTEM_SOUTH_GEORGIA_SOUTH_SANDWICH_ISLANDS'),
			'GT' => \JText::_('WTOTEM_GUATEMALA'),
			'GU' => \JText::_('WTOTEM_GUAM'),
			'GW' => \JText::_('WTOTEM_GUINEA-BISSAU'),
			'GY' => \JText::_('WTOTEM_GUYANA'),
			'HK' => \JText::_('WTOTEM_HONG_KONG_SAR_CHINA'),
			'HM' => \JText::_('WTOTEM_HEARD_MCDONALD_ISLANDS'),
			'HN' => \JText::_('WTOTEM_HONDURAS'),
			'HR' => \JText::_('WTOTEM_CROATIA'),
			'HT' => \JText::_('WTOTEM_HAITI'),
			'HU' => \JText::_('WTOTEM_HUNGARY'),
			'IC' => \JText::_('WTOTEM_CANARY_ISLANDS'),
			'ID' => \JText::_('WTOTEM_INDONESIA'),
			'IE' => \JText::_('WTOTEM_IRELAND'),
			'IL' => \JText::_('WTOTEM_ISRAEL'),
			'IM' => \JText::_('WTOTEM_ISLE_OF_MAN'),
			'IN' => \JText::_('WTOTEM_INDIA'),
			'IO' => \JText::_('WTOTEM_BRITISH_INDIAN_OCEAN_TERRITORY'),
			'IQ' => \JText::_('WTOTEM_IRAQ'),
			'IR' => \JText::_('WTOTEM_IRAN'),
			'IS' => \JText::_('WTOTEM_ICELAND'),
			'IT' => \JText::_('WTOTEM_ITALY'),
			'JE' => \JText::_('WTOTEM_JERSEY'),
			'JM' => \JText::_('WTOTEM_JAMAICA'),
			'JO' => \JText::_('WTOTEM_JORDAN'),
			'JP' => \JText::_('WTOTEM_JAPAN'),
			'KE' => \JText::_('WTOTEM_KENYA'),
			'KG' => \JText::_('WTOTEM_KYRGYZSTAN'),
			'KH' => \JText::_('WTOTEM_CAMBODIA'),
			'KI' => \JText::_('WTOTEM_KIRIBATI'),
			'KM' => \JText::_('WTOTEM_COMOROS'),
			'KN' => \JText::_('WTOTEM_ST_KITTS_NEVIS'),
			'KP' => \JText::_('WTOTEM_NORTH_KOREA'),
			'KR' => \JText::_('WTOTEM_SOUTH_KOREA'),
			'KW' => \JText::_('WTOTEM_KUWAIT'),
			'KY' => \JText::_('WTOTEM_CAYMAN_ISLANDS'),
			'KZ' => \JText::_('WTOTEM_KAZAKHSTAN'),
			'LA' => \JText::_('WTOTEM_LAOS'),
			'LB' => \JText::_('WTOTEM_LEBANON'),
			'LC' => \JText::_('WTOTEM_ST_LUCIA'),
			'LI' => \JText::_('WTOTEM_LIECHTENSTEIN'),
			'LK' => \JText::_('WTOTEM_SRI_LANKA'),
			'LR' => \JText::_('WTOTEM_LIBERIA'),
			'LS' => \JText::_('WTOTEM_LESOTHO'),
			'LT' => \JText::_('WTOTEM_LITHUANIA'),
			'LU' => \JText::_('WTOTEM_LUXEMBOURG'),
			'LV' => \JText::_('WTOTEM_LATVIA'),
			'LY' => \JText::_('WTOTEM_LIBYA'),
			'MA' => \JText::_('WTOTEM_MOROCCO'),
			'MC' => \JText::_('WTOTEM_MONACO'),
			'MD' => \JText::_('WTOTEM_MOLDOVA'),
			'ME' => \JText::_('WTOTEM_MONTENEGRO'),
			'MF' => \JText::_('WTOTEM_ST_MARTIN'),
			'MG' => \JText::_('WTOTEM_MADAGASCAR'),
			'MH' => \JText::_('WTOTEM_MARSHALL_ISLANDS'),
			'MK' => \JText::_('WTOTEM_NORTH_MACEDONIA'),
			'ML' => \JText::_('WTOTEM_MALI'),
			'MM' => \JText::_('WTOTEM_MYANMAR_BURMA'),
			'MN' => \JText::_('WTOTEM_MONGOLIA'),
			'MO' => \JText::_('WTOTEM_MACAO_SAR_CHINA'),
			'MP' => \JText::_('WTOTEM_NORTHERN_MARIANA_ISLANDS'),
			'MQ' => \JText::_('WTOTEM_MARTINIQUE'),
			'MR' => \JText::_('WTOTEM_MAURITANIA'),
			'MS' => \JText::_('WTOTEM_MONTSERRAT'),
			'MT' => \JText::_('WTOTEM_MALTA'),
			'MU' => \JText::_('WTOTEM_MAURITIUS'),
			'MV' => \JText::_('WTOTEM_MALDIVES'),
			'MW' => \JText::_('WTOTEM_MALAWI'),
			'MX' => \JText::_('WTOTEM_MEXICO'),
			'MY' => \JText::_('WTOTEM_MALAYSIA'),
			'MZ' => \JText::_('WTOTEM_MOZAMBIQUE'),
			'NA' => \JText::_('WTOTEM_NAMIBIA'),
			'NC' => \JText::_('WTOTEM_NEW_CALEDONIA'),
			'NE' => \JText::_('WTOTEM_NIGER'),
			'NF' => \JText::_('WTOTEM_NORFOLK_ISLAND'),
			'NG' => \JText::_('WTOTEM_NIGERIA'),
			'NI' => \JText::_('WTOTEM_NICARAGUA'),
			'NL' => \JText::_('WTOTEM_NETHERLANDS'),
			'NO' => \JText::_('WTOTEM_NORWAY'),
			'NP' => \JText::_('WTOTEM_NEPAL'),
			'NR' => \JText::_('WTOTEM_NAURU'),
			'NU' => \JText::_('WTOTEM_NIUE'),
			'NZ' => \JText::_('WTOTEM_NEW_ZEALAND'),
			'OM' => \JText::_('WTOTEM_OMAN'),
			'PA' => \JText::_('WTOTEM_PANAMA'),
			'PE' => \JText::_('WTOTEM_PERU'),
			'PF' => \JText::_('WTOTEM_FRENCH_POLYNESIA'),
			'PG' => \JText::_('WTOTEM_PAPUA_NEW_GUINEA'),
			'PH' => \JText::_('WTOTEM_PHILIPPINES'),
			'PK' => \JText::_('WTOTEM_PAKISTAN'),
			'PL' => \JText::_('WTOTEM_POLAND'),
			'PM' => \JText::_('WTOTEM_ST_PIERRE_MIQUELON'),
			'PN' => \JText::_('WTOTEM_PITCAIRN_ISLANDS'),
			'PR' => \JText::_('WTOTEM_PUERTO_RICO'),
			'PS' => \JText::_('WTOTEM_PALESTINIAN_TERRITORIES'),
			'PT' => \JText::_('WTOTEM_PORTUGAL'),
			'PW' => \JText::_('WTOTEM_PALAU'),
			'PY' => \JText::_('WTOTEM_PARAGUAY'),
			'QA' => \JText::_('WTOTEM_QATAR'),
			'QO' => \JText::_('WTOTEM_OUTLYING_OCEANIA'),
			'RE' => \JText::_('WTOTEM_REUNION'),
			'RO' => \JText::_('WTOTEM_ROMANIA'),
			'RS' => \JText::_('WTOTEM_SERBIA'),
			'RU' => \JText::_('WTOTEM_RUSSIA'),
			'RW' => \JText::_('WTOTEM_RWANDA'),
			'SA' => \JText::_('WTOTEM_SAUDI_ARABIA'),
			'SB' => \JText::_('WTOTEM_SOLOMON_ISLANDS'),
			'SC' => \JText::_('WTOTEM_SEYCHELLES'),
			'SD' => \JText::_('WTOTEM_SUDAN'),
			'SE' => \JText::_('WTOTEM_SWEDEN'),
			'SG' => \JText::_('WTOTEM_SINGAPORE'),
			'SH' => \JText::_('WTOTEM_ST_HELENA'),
			'SI' => \JText::_('WTOTEM_SLOVENIA'),
			'SJ' => \JText::_('WTOTEM_SVALBARD_JAN_MAYEN'),
			'SK' => \JText::_('WTOTEM_SLOVAKIA'),
			'SL' => \JText::_('WTOTEM_SIERRA_LEONE'),
			'SM' => \JText::_('WTOTEM_SAN_MARINO'),
			'SN' => \JText::_('WTOTEM_SENEGAL'),
			'SO' => \JText::_('WTOTEM_SOMALIA'),
			'SR' => \JText::_('WTOTEM_SURINAME'),
			'SS' => \JText::_('WTOTEM_SOUTH_SUDAN'),
			'ST' => \JText::_('WTOTEM_SAO_TOME_PRINCIPE'),
			'SV' => \JText::_('WTOTEM_EL_SALVADOR'),
			'SX' => \JText::_('WTOTEM_SINT_MAARTEN'),
			'SY' => \JText::_('WTOTEM_SYRIA'),
			'SZ' => \JText::_('WTOTEM_ESWATINI'),
			'TA' => \JText::_('WTOTEM_TRISTAN_DA_CUNHA'),
			'TC' => \JText::_('WTOTEM_TURKS_CAICOS_ISLANDS'),
			'TD' => \JText::_('WTOTEM_CHAD'),
			'TF' => \JText::_('WTOTEM_FRENCH_SOUTHERN_TERRITORIES'),
			'TG' => \JText::_('WTOTEM_TOGO'),
			'TH' => \JText::_('WTOTEM_THAILAND'),
			'TJ' => \JText::_('WTOTEM_TAJIKISTAN'),
			'TK' => \JText::_('WTOTEM_TOKELAU'),
			'TL' => \JText::_('WTOTEM_TIMOR-LESTE'),
			'TM' => \JText::_('WTOTEM_TURKMENISTAN'),
			'TN' => \JText::_('WTOTEM_TUNISIA'),
			'TO' => \JText::_('WTOTEM_TONGA'),
			'TR' => \JText::_('WTOTEM_TURKEY'),
			'TT' => \JText::_('WTOTEM_TRINIDAD_TOBAGO'),
			'TV' => \JText::_('WTOTEM_TUVALU'),
			'TW' => \JText::_('WTOTEM_TAIWAN'),
			'TZ' => \JText::_('WTOTEM_TANZANIA'),
			'UA' => \JText::_('WTOTEM_UKRAINE'),
			'UG' => \JText::_('WTOTEM_UGANDA'),
			'UM' => \JText::_('WTOTEM_US_OUTLYING_ISLANDS'),
			'US' => \JText::_('WTOTEM_UNITED_STATES'),
			'UY' => \JText::_('WTOTEM_URUGUAY'),
			'UZ' => \JText::_('WTOTEM_UZBEKISTAN'),
			'VA' => \JText::_('WTOTEM_VATICAN_CITY'),
			'VC' => \JText::_('WTOTEM_ST_VINCENT_GRENADINES'),
			'VE' => \JText::_('WTOTEM_VENEZUELA'),
			'VG' => \JText::_('WTOTEM_BRITISH_VIRGIN_ISLANDS'),
			'VI' => \JText::_('WTOTEM_US_VIRGIN_ISLANDS'),
			'VN' => \JText::_('WTOTEM_VIETNAM'),
			'VU' => \JText::_('WTOTEM_VANUATU'),
			'WF' => \JText::_('WTOTEM_WALLIS_FUTUNA'),
			'WS' => \JText::_('WTOTEM_SAMOA'),
			'XK' => \JText::_('WTOTEM_KOSOVO'),
			'YE' => \JText::_('WTOTEM_YEMEN'),
			'YT' => \JText::_('WTOTEM_MAYOTTE'),
			'ZA' => \JText::_('WTOTEM_SOUTH_AFRICA'),
			'ZM' => \JText::_('WTOTEM_ZAMBIA'),
			'ZW' => \JText::_('WTOTEM_ZIMBABWE'),
		];

		// Sort the list.
		natcasesort($countries);

		return $countries;
	}

	/**
	 * Get an array of country code => country name pairs, altered by alter hooks.
	 *
	 * @return array
	 *   An array of country code => country name pairs.
	 *
	 */
	public function getList() {
		// Populate the country list if it is not already populated.
		if (!isset($this->countries)) {
			$this->countries = static::getStandardList();
		}

		return $this->countries;
	}

}
