<?php
/**
 * @name		WebTotem Security
 * @package		pkg_wtotem
 * @copyright	Copyright (C) 2023. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		WebTotem team
 */


namespace WebTotem;

// No direct access
defined('_JEXEC') or die;
defined('WEBTOTEM_INIT') or die;

/**
 * WebTotem Database class for Joomla.
 */
class DB {

	const TABLE = '#__wtotem_settings';

	/**
	 * Add (or update) data to the table.
	 */
	public static function setData($options) {
		$table_name = static::TABLE;

		$db = \JFactory::getDbo();

		$query = $db->getQuery(true);
		if (self::getData($options['name'])) {
			$fields = array(
					$db->quoteName('name') . ' = ' . $db->quote($options['name']),
					$db->quoteName('value') . ' = ' . $db->quote($options['value']),
			);

			$conditions = array(
					$db->quoteName('name') . ' = ' . $db->quote($options['name']),
			);

			$query
					->update($db->quoteName($table_name))
					->set($fields)
					->where($conditions);

		} else {
			$columns = array('name', 'value');
			$values = array($db->quote($options['name']), $db->quote($options['value']));

			$query
					->insert($db->quoteName($table_name))
					->columns($db->quoteName($columns))
					->values(implode(',', $values));
		}

		$db->setQuery($query);
		$db->execute();

	}

	/**
	 * Getting values from the table.
	 *
	 * @param string $name
	 *    Option name.
	 *
	 * @return array
	 */
	public static function getData($name) {
		$table_name = static::TABLE;
		$db = \JFactory::getDbo();

		$query = $db
				->getQuery(true)
				->select(['name', 'value'])
				->from($db->quoteName($table_name))
				->where($db->quoteName('name') . " = " . $db->quote($name));

		$db->setQuery($query);
		return $db->loadAssocList('name', 'value');
	}

	/**
	 * Delete data from the table.
	 */
	public static function deleteData($name) {

		$table_name = static::TABLE;
		$db = \JFactory::getDbo();

		$query = $db->getQuery(true);

		$conditions = array(
				$db->quoteName('name') . ' = ' . $db->quote($name),
		);

		$query->delete($db->quoteName($table_name));
		$query->where($conditions);

		$db->setQuery($query);
		$db->execute();

	}

}
