<?php
/**
 * @name		WebTotem Security
 * @package		pkg_wtotem
 * @copyright	Copyright (C) 2023. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		WebTotem team
 */


Namespace WebTotem;

// No direct access to this file
defined('_JEXEC') or die;
use Joomla\CMS\Uri\Uri;

/**
 * Read, parse and handle everything related with the templates.
 */
class Template {

	protected $images_path;

	function __construct() {
		$this->images_path = WTOTEM_MEDIA_URI .'/images/';
	}

	/**
	 * Rendering a template using twig and filling in data.
	 *
	 * @param string $template
	 * @param array $variables
	 *
	 * @return bool|string
	 */
	public function render( $template, $variables = [] ) {

		if ( ! file_exists( WTOTEM_PATH . '/templates/' . $template ) ) {
			Option::setNotification( 'error', \JText::_('WTOTEM_THERE_IS_NO_TEMPLATE') . $template );

			return false;
		}

		$root_path = \JUri::root(true);
		$token = \JFactory::getSession()->getFormToken();

		// Default values of some variables
		$variables['lang'] = Helper::getLanguage();
		$variables['days'] = (isset($variables['days'])) ? $variables['days'] : 7;
		$variables['images_path'] = $this->images_path;
		$variables['ajax_url'] = $root_path . '/administrator/index.php?option=com_wtotem&task=ajax&' . $token . '=1';

		return $this->getHtml( $template, $variables );
	}

	/**
	 * Page rendering based on array data.
	 *
	 * @param $params
	 *
	 * @return bool|string
	 */
	public function arrayRender( $params ) {

		$render = '';
		if ( is_array( $params ) ) {

			if ( array_key_exists( 'template', $params ) ) {
				$template  = $params['template'] . '.php';
				$variables = ( isset( $params['variables'] ) ) ? $params['variables'] : [];

				$render = $this->render( $template, $variables ) ?: '';
			} else {
				foreach ( $params as $param ) {
					$template  = $param['template'] . '.php';
					$variables = ( isset( $param['variables'] ) ) ? $param['variables'] : [];

					$render .= $this->render( $template, $variables ) ?: '';
				}
			}

		}

		return $render;
	}

	/**
	 * Generate a page based on a basic template and content.
	 *
	 * @param $page_content
	 *
	 * @return bool|string
	 */
	public function baseTemplate( $page_content ) {
		$input = Helper::getInput();
		$page = $input->get('task', 'dashboard');

		$variables['is_active'][$page] = 'wtotem_nav__link_active';
		$variables['theme_mode'] = Helper::getThemeMode();
		$variables['notifications'] = Helper::getNotifications();
		$variables['url'] = WTOTEM_URL . '&task=';
		$variables['current_year']  = date('Y');;
		$variables['content']  = $page_content;

		return $this->render( 'layout.php', $variables );
	}


	/**
	 * Get HTML without Twig
	 *
	 * @return string|bool
	 */
	public function getHtml( $template, $variables ) {
		$templatePath = WTOTEM_PATH . '/templates/' . $template;
		if ( ! file_exists( $templatePath ) ) {
			return false;
		}

		ob_start();
		include $templatePath;

		return ob_get_clean();
	}

}
