<?php
/**
 * @name		WebTotem Security
 * @package		pkg_wtotem
 * @copyright	Copyright (C) 2023. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @author		WebTotem team
 */

defined('_JEXEC') or die;


class plgSystemWtotemPlg extends JPlugin {

	/**
	 * Constructor.
	 *
	 * @param object &$subject The object to observe.
	 * @param array $config An optional associative array of configuration settings.
	 *
	 * @since 1.0
	 */
	public function __construct(&$subject, $config) {
		// Calling the parent Constructor
		parent::__construct($subject, $config);

		// Do some extra initialisation in this constructor if required
	}

	/**
	 * Listener for the `onAfterInitialise` event
	 *
	 * @return void
	 *
	 * @since 1.0
	 */
	public function onAfterInitialise() {

		self::getUserRole();

		if ($waf = self::getOption("waf_file")) {
			$include_waf_file = JPATH_SITE . '/_include_' . $waf;

			if (is_file($include_waf_file) && is_readable($include_waf_file)) {
				include_once $include_waf_file;
			}
		}
	}

	/**
	 * Define role of current user.
	 *
	 */
	public static function getUserRole() {

		if (defined('WEBTOTEM_USER_ROLE')) {
			return true;
		}

		$user = \JFactory::getUser();
		$user_groups = $user->groups;

		// include WAF. Except: 8 - superadmin, 7 - admin
		if(in_array(8, $user_groups) or in_array(7, $user_groups) ) {
			$user_role = 1;
		} elseif($user->authorise('core.edit', 'com_content')) {
			$user_role = 2;
		} else {
			$user_role = 0;
		}

		define( 'WEBTOTEM_USER_ROLE', $user_role );

		return true;
	}

	/**
	 * Get config option.
	 *
	 * @param string $name
	 *   Option name.
	 *
	 * @return mixed
	 *   Returns saved data by option name.
	 */
	public static function getOption($name) {
		$data = self::getData($name);
		return $data[$name] ?? false;
	}

	/**
	 * Getting values from the table.
	 *
	 * @param string $name
	 *    Option name.
	 *
	 * @return array
	 */
	public static function getData($name) {

		$table_name = '#__wtotem_settings';
		$db = \JFactory::getDbo();

		$prefix = $db->getPrefix();
		$results = $db->setQuery('SHOW TABLES')->loadColumn();
		if (!in_array($prefix . 'wtotem_settings', $results)) {
			return [];
		}

		$query = $db
			->getQuery(true)
			->select(['name', 'value'])
			->from($db->quoteName($table_name))
			->where($db->quoteName('name') . " = " . $db->quote($name));

		$db->setQuery($query);
		return $db->loadAssocList('name', 'value');
	}

}
?>
